@@ -14,6 +14,7 @@ from test_server import (
     WaitTimeoutError,
     TestServerError,
     Response,
+    Request,
     RequestNotProcessed,
 )
 import test_server
@@ -21,7 +22,7 @@ import test_server
 from .util import fixture_global_server, fixture_server  # pylint: disable=unused-import
 
 NETWORK_TIMEOUT = 1
-EXTRA_PORT = 10100
+SPECIFIC_TEST_PORT = 10100
 pool = PoolManager()
 
 
@@ -45,7 +46,6 @@ def request(
         params["body"] = data
     if not method:
         method = "POST" if (data or fields) else "GET"
-    print("~" * 10, method, url, params)
     return pool.request(method, url, **params)
 
 
@@ -136,7 +136,7 @@ def test_method_sleep(server: TestServer) -> None:
 
 
 def test_request_done_after_start(server: TestServer) -> None:
-    server = TestServer(port=EXTRA_PORT)
+    server = TestServer()
     try:
         server.start()
         assert not server.request_is_done()
@@ -207,7 +207,7 @@ def test_options_method(server: TestServer) -> None:
 
 def test_multiple_start_stop_cycles() -> None:
     for cnt in range(30):
-        server = TestServer(port=EXTRA_PORT + cnt)
+        server = TestServer()
         server.start()
         try:
             server.add_response(Response(data=b"zorro"), count=10)
@@ -219,7 +219,7 @@ def test_multiple_start_stop_cycles() -> None:
 
 
 def test_specific_port() -> None:
-    server = TestServer(address="localhost", port=EXTRA_PORT)
+    server = TestServer(address="localhost", port=SPECIFIC_TEST_PORT)
     try:
         server.start()
         server.add_response(Response(data=b"abc"))
@@ -244,22 +244,6 @@ def test_null_bytes(server: TestServer) -> None:
     assert unquote(server.get_request().path) == "/\x00/"
 
 
-# def send_get_request(host, port, path):
-#    sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
-#    sock.connect((host, port))
-#    data = (
-#        b'GET %s HTTP/1.1\r\n'
-#        b'Host: %s\r\n'
-#        b'\r\n'
-#        #% (quote(path, safe='/').encode('utf-8'), host.encode('utf-8'))
-#        % (path, host.encode('utf-8'))
-#    )
-#    sock.send(data)
-#    data = sock.recv(1024 * 10)
-#    sock.close()
-#    return data
-
-
 def test_callback(server: TestServer) -> None:
     def get_callback():
         return {
@@ -303,12 +287,12 @@ def test_response_data_invalid_type(server: TestServer) -> None:
 
 
 def test_stop_not_started_server() -> None:
-    server = TestServer(port=EXTRA_PORT)
+    server = TestServer()
     server.stop()
 
 
 def test_start_request_stop_same_port() -> None:
-    server = TestServer(port=EXTRA_PORT)
+    server = TestServer()
     for _ in range(10):
         try:
             server.start()
@@ -420,11 +404,12 @@ def test_add_response_count_two(server: TestServer) -> None:
 
 def test_raw_callback(server):
     def callback():
-        return b"HTTP/1.1 200 OK\nFoo: Bar\nGaz: Baz\nContent-Length: 5\n\nhello"
+        return b"HTTP/1.0 200 OK\nFoo: Bar\nGaz: Baz\nContent-Length: 5\n\nhello"
 
     server.add_response(Response(raw_callback=callback))
     res = request(server.get_url())
     assert "foo" in res.headers
+    assert b"hello" == res.data
 
 
 def test_raw_callback_invalid_type(server):
@@ -434,3 +419,15 @@ def test_raw_callback_invalid_type(server):
     server.add_response(Response(raw_callback=callback))
     res = request(server.get_url())
     assert b"must return bytes" in res.data
+
+
+def test_request_property(server):
+    server.add_response(Response())
+    request(server.get_url())
+    assert isinstance(server.request, Request)
+
+
+def test_put_request(server):
+    server.add_response(Response())
+    request(server.get_url(), data=b"foo", method="put")
+    assert server.request.method == "PUT"
